package com.cloudcross.ssp.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.cloudcross.ssp.base.dao.GenericIBatisDao;
import com.cloudcross.ssp.common.utils.MapBuilder;
import com.cloudcross.ssp.model.DspAgent;
import com.cloudcross.ssp.service.IDspAgentService;

/**
 * 创建人：rongying
 * 创建时间：2015.12.11
 * dsp账户服务接口实现
 */

@Service
public class DspAgentService implements IDspAgentService{
	
	@Autowired
	private GenericIBatisDao myBatisDao;

	/**
	 * 批量添加dsp账户
	 * 
	 * @param list
	 *            实体对象
	 * @return <code>true</code>代表成功，否则代表失败。
	 */
	@Override
	public boolean add(List<DspAgent> list) {
		myBatisDao.save("dspAgentSqlMapper.add", MapBuilder.create(HashMap.class)
				.add("dspAgentList",list).map());
		return true;
	}
	
	/**
	 * 批量编辑dsp账户
	 * 
	 * @param list
	 *            实体对象
	 * @return <code>true</code>代表成功，否则代表失败。
	 */
	@Override
	public boolean update(List<DspAgent> list) {
		myBatisDao.save("dspAgentSqlMapper.update", MapBuilder.create(HashMap.class)
				.add("dspAgentList",list).map());
		return true;
	}

	/**
	 * 获取所有dsp账户
	 * 
	 * @param map
	 *            实体对象
	 * @return 符合条件的列表记录
	 */
	@Override
	public List<DspAgent> getAll(Map<String, Object> map) {
		return myBatisDao.getList("dspAgentSqlMapper.getAll", map);
	}

	/**
	 * 根据id获取对应的dsp账户
	 * 
	 * @param map
	 *            实体对象
	 * @return 符合条件的列表记录
	 */
	@Override
	public List<DspAgent> get(Map<String, Object> map) {
		@SuppressWarnings("unchecked")
		List<Long> idList = (List<Long>) map.get("idList");
		return myBatisDao.getList("dspAgentSqlMapper.get", MapBuilder.create(HashMap.class)
				.add("idList",idList).map());
	}

	/**
	 * 验证dsp账户是否符合
	 * 
	 * @param dspAgent
	 * 				实体对象
	 * @return 0代表不符合，否则代表符合。
	 */
	@Override
	public int isCheck(DspAgent dspAgent) {
		return myBatisDao.get("dspAgentSqlMapper.isCheck", dspAgent);
	}

	/**
	 * 查询最大的id - 插入时获取
	 * 
	 * @param paramMap
	 * 				名称和token
	 * @return 下一个id的值
	 */
	@Override
	public Long selectMaxId(Map<String,Object> paramMap) {
		// TODO Auto-generated method stub
		return myBatisDao.get("dspAgentSqlMapper.selectMaxId",paramMap);
	}

}
