package com.cloudcross.ssp.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.cloudcross.ssp.base.dao.GenericIBatisDao;
import com.cloudcross.ssp.common.utils.MapBuilder;
import com.cloudcross.ssp.model.DspBanner;
import com.cloudcross.ssp.service.IDspBannerService;

/**
 * 创建人：rongying
 * 创建时间：2015.12.11
 * dsp-广告主-创意服务接口实现
 */

@Service
public class DspBannerService implements IDspBannerService{
	
	@Autowired
	private GenericIBatisDao myBatisDao;

	/**
	 * 添加dsp广告主对应的创意
	 * 
	 * @param list
	 *            实体对象
	 * @return <code>true</code>代表成功，否则代表失败。
	 */
	@Override
	public boolean add(List<DspBanner> list) {
		myBatisDao.save("dspBannerSqlMapper.add", MapBuilder.create(HashMap.class)
				.add("dspBannerList",list).map());
		return true;
	}

	/**
	 * 编辑dsp广告主对应的创意
	 * 
	 * @param list
	 *            实体对象
	 * @return <code>true</code>代表成功，否则代表失败。
	 */
	@Override
	public boolean update(List<DspBanner> list) {
		myBatisDao.save("dspBannerSqlMapper.update", MapBuilder.create(HashMap.class)
				.add("dspBannerList",list).map());
		return true;
	}

	/**
	 * 获取dsp广告主对应的所有创意
	 * 
	 * @param map
	 *            实体对象
	 * @return 符合条件的列表记录
	 */
	@Override
	public List<DspBanner> getAll(Map<String, Object> map) {
		return myBatisDao.getList("dspBannerSqlMapper.getAll", map);
	}

	/**
	 * 根据条件获取对应的创意
	 * 
	 * @param map
	 *            实体对象
	 * @return 符合条件的列表记录
	 */
	@Override
	public List<DspBanner> get(Map<String, Object> map) {
		return myBatisDao.getList("dspBannerSqlMapper.get", map);
	}
	
	/**
	 * 查询最大的id - 插入时获取
	 * 
	 * @param paramMap
	 * 				dspId和advertiserId
	 * @return 下一个id的值
	 */
	@Override
	public Long selectMaxId(Map<String, Long> paramMap) {
		// TODO Auto-generated method stub
		return myBatisDao.get("dspBannerSqlMapper.selectMaxId",paramMap);
	}
	
	/**
	 * 批量查询创意审核的状态
	 * 
	 * @param paramMap
	 * 				bannerIds
	 * @return 符合条件的记录
	 */
	public List<Map<String,Object>> queryState(Map<String,Object> paramMap){
		return myBatisDao.getList("dspBannerSqlMapper.queryState",paramMap);
	}

}
